@@ -1,21 +1,7 @@
 /*
- * Copyright 2014 Jeremy Whiting <jpwhiting@kde.org>
+ * SPDX-FileCopyrightText: 2014 Jeremy Whiting <jpwhiting@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "fifteenimageprovider.h"
@@ -23,10 +9,10 @@
 #include <QDebug>
 
 FifteenImageProvider::FifteenImageProvider()
-: QQuickImageProvider(QQuickImageProvider::Pixmap)
-, m_boardSize(4)
-, m_pieceWidth(30)
-, m_pieceHeight(30)
+    : QQuickImageProvider(QQuickImageProvider::Pixmap)
+    , m_boardSize(4)
+    , m_pieceWidth(30)
+    , m_pieceHeight(30)
 {
 }
 
@@ -67,8 +53,9 @@ QPixmap FifteenImageProvider::requestPixmap(const QString &id, QSize *size, cons
             update = true;
         }
 
-        if (update)
+        if (update) {
             updatePixmaps();
+        }
 
         int number = idParts.at(1).toInt();
 
@@ -98,4 +85,3 @@ void FifteenImageProvider::updatePixmaps()
         m_pixmaps[i] = copyPixmap.copy(posX, posY, m_pieceWidth, m_pieceHeight);
     }
 }
-
