@@ -17,9 +17,6 @@ class GroupingContainment : public Plasma::Containment
     Q_OBJECT
 public:
     explicit GroupingContainment(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-    ~GroupingContainment() override;
-
-    void init() override;
 
     // Creates an applet
     Q_INVOKABLE void newTask(const QString &task);
