@@ -13,7 +13,7 @@
 #include <QMutex>
 #include <QSharedPointer>
 
-using namespace Plasma;
+using namespace KRunner;
 
 /**
  * This checks the spelling of query
@@ -23,22 +23,17 @@ class SpellCheckRunner : public AbstractRunner
     Q_OBJECT
 
 public:
-    SpellCheckRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    SpellCheckRunner(QObject *parent, const KPluginMetaData &metaData);
     ~SpellCheckRunner() override;
 
     void match(RunnerContext &context) override;
     void run(const RunnerContext &context, const QueryMatch &action) override;
 
     void reloadConfiguration() override;
-
-protected Q_SLOTS:
-    void init() override;
     QMimeData *mimeDataForMatch(const QueryMatch &match) override;
 
-    void loadData();
-    void destroydata();
-
 private:
+    void loadData();
     QString findLang(const QStringList &terms);
 
     QString m_triggerWord;
@@ -46,7 +41,6 @@ private:
     QMap<QString, QString> m_languages; // key=language name, value=language code
     bool m_requireTriggerWord;
     QMap<QString, QSharedPointer<Sonnet::Speller>> m_spellers; // spellers
-    QMutex m_spellLock; // Lock held when constructing a new speller
 
     friend class SpellCheckRunnerTest;
 };
